<template>
  <div class="mod-config">
    <basic-container>
      <el-row>
        <el-col :span="8">
          <ttable
            :table="table"
            @currentChange="handleCurrentChange"
            :uploadInfo="uploadInfo"
            :prelang="prelang"
            :options="options"
            :ajaxFun="ajaxFun"
            ref="crewTable"
          >
            <template #toolbar></template>
          </ttable>
        </el-col>
        <el-col :span="16">
          <ttable
            :table="staffTable"
            :uploadInfo="staffUploadInfo"
            :prelang="staffPrelang"
            :options="staffOptions"
            :ajaxFun="staffajaxFun"
            :paramObj="paramObj"
            ref="staffTable"
          >
            <template #toolbar></template>
          </ttable>
        </el-col>
        <!-- 弹窗, 新增 / 修改 -->
      </el-row>
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      ></table-form>
      <staffDialog
        :currshowlist.sync="showStaff"
        :paramSelCol="paramSelCol"
        :paramSelArr="paramSelArr"
        :multiSelect="true"
        @handleSelectionChange="selectStaff"
      />
    </basic-container>
  </div>
</template>

<script>
import { delObj, fetchList } from '@/api/basic/crew'
import TableForm from './crew-form'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table.vue'
import staffDialog from '@/views/common/staff.vue'
import {
  addStaff,
  delStaff,
  getStaffPage,
  getStaffList
} from '../../../api/basic/crew'

export default {
  data() {
    return {
      paramSelArr: [],
      paramSelCol: 'staffNo',
      crewList: {},
      showStaff: false,
      ajaxFun: fetchList,
      addOrUpdateVisible: false,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: '/mes/crew/upload'
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: false, //
        seqNo: true,
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            minWidth: '140',
            prop: 'crewName',
            label: '班组',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.addOrUpdateHandle }
          }
        ],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            fun: this.addOrUpdateHandle
          }
        ],
        operator: [
          {
            text: '删除',
            icon: 'el-icon-delete',
            type: 'text',
            size: 'small',
            fun: this.deleteHandle
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      },
      crewId: null,
      paramObj: { crewId: 0 },
      staffajaxFun: getStaffPage,
      staffMultipleSelection: [],
      staffUploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      staffPrelang: 'operation',
      staffOptions: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      staffTable: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        staffList: [],
        // 标题
        column: [
          // 人员编号
          {
            minWidth: '30',
            prop: 'staffNo',
            label: '人员编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 人员名称
          {
            minWidth: '120',
            prop: 'staffName',
            label: '人员名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 人员系数
          {
            minWidth: '120',
            prop: 'personnelFactor',
            label: '人员系数',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 部门
          {
            minWidth: '120',
            prop: 'divisionName',
            label: '部门',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 电话
          {
            minWidth: '120',
            prop: 'phone',
            label: '电话',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 邮箱
          {
            minWidth: '120',
            prop: 'email',
            label: '邮箱',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 岗位
          {
            minWidth: '120',
            prop: 'post',
            label: '岗位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 创建时间
          {
            minWidth: '140',
            prop: 'createTime',
            label: '创建时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          },
          // 更新时间
          {
            minWidth: '120',
            prop: 'updateTime',
            label: '更新时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          },
          // 创建者
          {
            minWidth: '200',
            prop: 'createUser',
            label: '创建者',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 更新者
          {
            minWidth: '200',
            prop: 'updateUser',
            label: '更新者',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          }
        ],
        toolbar: [
          {
            text: '添加',
            type: 'primary',
            fun: this.addHandle
          }
        ],
        operator: [
          {
            text: '删除',
            type: 'text',
            size: 'small',
            fun: this.deleteStaff
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      }
    }
  },
  components: {
    staffDialog,
    TableForm,
    ttable
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  methods: {
    // 获取数据列表
    getData() {
      this.$refs.crewTable.getDataList()
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(row == null ? null : row.id)
      })
    },
    handleCurrentChange(row) {
      this.crewId = row.id
      this.paramObj = { crewId: row.id }
      this.$nextTick(() => {
        this.getStaff()
      })
    },
    getStaff() {
      this.$refs.staffTable.getDataList()
    },
    addHandle() {
      if (this.crewId == null) {
        this.$message.error('请先选择一个班组')
      } else {
        // 筛选出当前申请已有的零件
        this.paramSelArr = []
        getStaffList(Object.assign({ id: this.crewId })).then((response) => {
          if (response.data.data) {
            response.data.data.forEach((e) => {
              this.paramSelArr.push(e.staffNo)
            })
          }
          this.showStaff = true
        })
      }
    },
    // 选中员工，并记录员工上机信息
    selectStaff(staffs) {
      if (staffs) {
        this.$nextTick(() => {
          this.crewList = { staffList: staffs, id: this.crewId }
          addStaff(this.crewList).then((data) => {
            this.$message.success('添加人员成功')
            this.visible = false
            this.getStaff()
          })
        })
      }
    },
    deleteStaff(row) {
      var newStaffList = []
      newStaffList.push(row)
      this.crewList = { id: this.crewId, staffList: newStaffList }
      delStaff(this.crewList).then((data) => {
        this.$message.success('删除人员成功')
        this.visible = false
        this.getStaff()
      })
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认删除班次名称为：' + row.crewName, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delObj(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    }
  }
}
</script>
